@@ -7,13 +7,15 @@ This project provides specialized code generation, script creation, and developm
 automation capabilities designed specifically for AI agents.
 """
 
-__version__ = "0.3.1"
+__version__ = "0.3.3"
 
 # Import migrated modules
 from . import analysis, database, git, profiling, python, quality, shell
 
 # Import helper functions
 from .helpers import (
+    get_tool_info,
+    list_all_available_tools,
     load_all_analysis_tools,
     load_all_database_tools,
     load_all_git_tools,
@@ -35,6 +37,8 @@ __all__: list[str] = [
     "quality",
     "shell",
     # Helper functions
+    "get_tool_info",
+    "list_all_available_tools",
     "load_all_analysis_tools",
     "load_all_database_tools",
     "load_all_git_tools",
