@@ -7,28 +7,12 @@ credentials, and sensitive information using pattern matching.
 import os
 import re
 from re import Pattern
-from typing import Any, Callable
+from typing import Any
 
-from coding_open_agent_tools.analysis.patterns import (
-    get_all_patterns,
-)
+from coding_open_agent_tools._decorators import adk_tool, strands_tool
+from coding_open_agent_tools.analysis.patterns import get_all_patterns
 from coding_open_agent_tools.exceptions import CodeAnalysisError
 
-try:
-    from strands import tool as strands_tool
-except ImportError:
-    # Create a no-op decorator if strands is not installed
-    def strands_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
-
-
-try:
-    from google.adk.tools import tool as adk_tool
-except ImportError:
-    # Create a no-op decorator if google-adk is not installed
-    def adk_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
-
 
 @adk_tool
 @strands_tool
