@@ -9,22 +9,10 @@ This module provides validation functions to catch errors before execution:
 
 import ast
 import re
-from typing import Any, Callable
+from typing import Any
 
-try:
-    from strands import tool as strands_tool
-except ImportError:
-    # Create a no-op decorator if strands is not installed
-    def strands_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
-
-
-try:
-    from google.adk.tools import tool as adk_tool
-except ImportError:
-    # Create a no-op decorator if google-adk is not installed
-    def adk_tool(func: Callable[..., Any]) -> Callable[..., Any]:  # type: ignore[no-redef]
-        return func
+from coding_open_agent_tools._decorators import adk_tool, strands_tool
+from coding_open_agent_tools.types import STDLIB_MODULES
 
 
 @adk_tool
@@ -493,58 +481,9 @@ def _classify_import(import_name: str) -> str:
     Returns:
         One of: "stdlib", "third_party", "local"
     """
-    # Standard library modules (common ones)
-    stdlib_modules = {
-        "abc",
-        "argparse",
-        "ast",
-        "asyncio",
-        "base64",
-        "collections",
-        "contextlib",
-        "copy",
-        "csv",
-        "dataclasses",
-        "datetime",
-        "decimal",
-        "enum",
-        "functools",
-        "hashlib",
-        "http",
-        "inspect",
-        "io",
-        "itertools",
-        "json",
-        "logging",
-        "math",
-        "os",
-        "pathlib",
-        "pickle",
-        "platform",
-        "random",
-        "re",
-        "shutil",
-        "socket",
-        "sqlite3",
-        "string",
-        "subprocess",
-        "sys",
-        "tempfile",
-        "threading",
-        "time",
-        "traceback",
-        "typing",
-        "unittest",
-        "urllib",
-        "uuid",
-        "warnings",
-        "weakref",
-        "xml",
-    }
-
     base_module = import_name.split(".")[0]
 
-    if base_module in stdlib_modules:
+    if base_module in STDLIB_MODULES:
         return "stdlib"
     elif base_module.startswith("_"):  # Private/local modules often start with _
         return "local"
